@@ -138,10 +138,10 @@ class HttpCaller(object):
             else:
                 rsp: Response = requests.post(url=url, headers=headers, data=req_bytes)
         except BaseException as e:
-            if "timeout" in str(e).lower():
-                log.error("[ByteplusSDK] do http request timeout, msg:%s", e)
+            if self._is_timeout_exception(e):
+                log.error("[ByteplusSDK] do http request timeout, url:%s msg:%s", url, e)
                 raise NetException(str(e))
-            log.error("[ByteplusSDK] do http request occur io exception, msg:%s", e)
+            log.error("[ByteplusSDK] do http request occur io exception, url:%s msg:%s", url, e)
             raise BizException(str(e))
         finally:
             cost = int((time.time() - start) * 1000)
@@ -149,16 +149,23 @@ class HttpCaller(object):
         # log.debug("[ByteplusSDK][HTTPCaller] URL:%s Response Headers:\n%s", url, str(rsp.headers))
         if rsp.status_code != _SUCCESS_HTTP_CODE:
             self._log_rsp(url, rsp)
-            raise BizException("code:%d msg:%s".format(rsp.status_code, rsp.reason))
+            raise BizException("code:{} msg:{}".format(rsp.status_code, rsp.reason))
         return rsp.content
 
+    @staticmethod
+    def _is_timeout_exception(e):
+        lower_err_msg = str(e).lower()
+        if "time" in lower_err_msg and "out" in lower_err_msg:
+            return True
+        return False
+
     @staticmethod
     def _log_rsp(url: str, rsp: Response) -> None:
         rsp_bytes = rsp.content
         if rsp_bytes is not None and len(rsp.content) > 0:
-            log.error("[ByteplusSDK] http status not 200, url:%s code:%d msg:%s body:%s",
-                      url, rsp.status_code, rsp.reason, str(rsp_bytes))
+            log.error("[ByteplusSDK] http status not 200, url:%s code:%d msg:%s headers:\n%s body:\n%s",
+                      url, rsp.status_code, rsp.reason, str(rsp.headers), str(rsp_bytes))
         else:
-            log.error("[ByteplusSDK] http status not 200, url:%s code:%d msg:%s",
-                      url, rsp.status_code, rsp.reason)
+            log.error("[ByteplusSDK] http status not 200, url:%s code:%d msg:%s headers:\n%s",
+                      url, rsp.status_code, rsp.reason, str(rsp.headers))
         return
